Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(191)

Unified Diff: third_party/WebKit/Source/core/dom/custom/CustomElement.h

Issue 2277713002: Rename CustomElementsRegistry to CustomElementRegistry (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: rebase Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/core/dom/custom/CustomElement.h
diff --git a/third_party/WebKit/Source/core/dom/custom/CustomElement.h b/third_party/WebKit/Source/core/dom/custom/CustomElement.h
index 51c299f2853146d7c615e8d1cb386f932565bc0c..ec8f3c1546b5e74181b1b0e7f308088f848439f2 100644
--- a/third_party/WebKit/Source/core/dom/custom/CustomElement.h
+++ b/third_party/WebKit/Source/core/dom/custom/CustomElement.h
@@ -24,11 +24,11 @@ class CustomElementRegistry;
class CORE_EXPORT CustomElement {
STATIC_ONLY(CustomElement);
public:
// Retrieves the CustomElementsRegistry for Element, if any. This
// may be a different object for a given element over its lifetime
// as it moves between documents.
- static CustomElementsRegistry* registry(const Element&);
- static CustomElementsRegistry* registry(const Document&);
+ static CustomElementRegistry* registry(const Element&);
+ static CustomElementRegistry* registry(const Document&);
static CustomElementDefinition* definitionForElement(const Element*);
« no previous file with comments | « third_party/WebKit/Source/core/dom/Element.cpp ('k') | third_party/WebKit/Source/core/dom/custom/CustomElement.cpp » ('j') | no next file with comments »
@@ -24,11 +24,11 @@ class CustomElementRegistry;
STATIC_ONLY(CustomElement);
public:
- // Retrieves the CustomElementsRegistry for Element, if any. This
+ // Retrieves the CustomElementRegistry for Element, if any. This
// may be a different object for a given element over its lifetime
// as it moves between documents.

Powered by Google App Engine
This is Rietveld 408576698